aboutsummaryrefslogtreecommitdiff
path: root/backend/db
diff options
context:
space:
mode:
Diffstat (limited to 'backend/db')
-rw-r--r--backend/db/db.go5
-rw-r--r--backend/db/schemas.go1
2 files changed, 4 insertions, 2 deletions
diff --git a/backend/db/schemas.go b/backend/db/schemas.go
index bdfa60c..62c5a11 100644
--- a/backend/db/schemas.go
+++ b/backend/db/schemas.go
@@ -12,4 +12,5 @@ type Paste struct {
Hash string
Content string
Expiry time.Time `bson:"expiry"`
+ Title string
}
diff --git a/backend/db/db.go b/backend/db/db.go
index 053ba87..4f638fd 100644
--- a/backend/db/db.go
+++ b/backend/db/db.go
@@ -24,8 +24,8 @@ func init() {
initSessions(mUser, mPass, mIP)
}
-// creates a new paste with content and hash
-func New(ip, content, expiry string) error {
+// creates a new paste with title, content and hash
+func New(ip, content, expiry, title string) error {
// generate hash from ip
hash := hashing.GenerateURI(ip)
@@ -33,6 +33,7 @@ func New(ip, content, expiry string) error {
new := Paste{
Hash: hash,
Content: content,
+ Title: title,
}
// check if expiry